pub struct ParseBudgets {
pub max_ifds: usize,
pub max_ifd_entries: usize,
pub max_tag_value_bytes: usize,
pub max_metadata_value_bytes: usize,
}Expand description
Budgets that bound TIFF IFD parsing allocations.
Fields
max_ifds: usizeMaximum number of IFDs to follow in a chain.
max_ifd_entries: usizeMaximum tag entries allowed in one IFD.
max_tag_value_bytes: usizeMaximum encoded value bytes allowed for one tag value.
max_metadata_value_bytes: usizeMaximum encoded value bytes allowed across all parsed tag values.