MmapSource

Struct MmapSource 

pub struct MmapSource { /* private fields */ }
Memory-mapped file source.

Implementations

Source

impl MmapSource

pub unsafe fn open(path: &Path) -> Result<Self>

Open a file-backed source by memory-mapping the whole file.

Safety

The caller must guarantee that the mapped file is not mutated or truncated for the lifetime of the returned source. This includes writes through other file handles and writes from other processes.