TiffFile

Struct TiffFile 

pub struct TiffFile { /* private fields */ }
A TIFF file handle.

Implementations

Source

impl TiffFile

pub fn open<P: AsRef<Path>>(path: P) -> Result<Self>

Open a TIFF file from disk using safe file-backed I/O.

pub fn open_with_options<P: AsRef<Path>>( path: P, options: OpenOptions, ) -> Result<Self>

Open a TIFF file from disk using safe file-backed I/O with explicit decoder options.

pub unsafe fn open_mmap<P: AsRef<Path>>(path: P) -> Result<Self>

Open a TIFF file from disk using memory-mapped I/O.

Safety

The caller must guarantee that the mapped file is not mutated or truncated while the returned TiffFile is alive. This includes writes through other file handles and writes from other processes.

pub unsafe fn open_mmap_with_options<P: AsRef<Path>>( path: P, options: OpenOptions, ) -> Result<Self>

Open a TIFF file from disk using memory-mapped I/O with explicit decoder options.

Safety

The caller must guarantee that the mapped file is not mutated or truncated while the returned TiffFile is alive. This includes writes through other file handles and writes from other processes.

pub fn from_bytes(data: Vec<u8>) -> Result<Self>

Open a TIFF file from an owned byte buffer (WASM-compatible).

pub fn from_bytes_with_options( data: Vec<u8>, options: OpenOptions, ) -> Result<Self>

Open a TIFF file from bytes with explicit decoder options.

pub fn from_source(source: SharedSource) -> Result<Self>

Open a TIFF file from an arbitrary random-access source.

pub fn from_source_with_options( source: SharedSource, options: OpenOptions, ) -> Result<Self>

Open a TIFF file from an arbitrary random-access source with options.

pub fn byte_order(&self) -> ByteOrder

Returns the byte order of the TIFF file.

pub fn is_bigtiff(&self) -> bool

Returns true if this is a BigTIFF file.

pub fn ifd_count(&self) -> usize

Returns the number of IFDs (images/pages) in the file.

pub fn ifd(&self, index: usize) -> Result<&Ifd>

Returns the IFD at the given index.

pub fn ifds(&self) -> &[Ifd]

Returns all parsed IFDs.

pub fn raw_bytes(&self) -> Option<&[u8]>

Returns the raw file bytes when the source exposes a resident immutable slice.

This returns Some for in-memory and memory-mapped sources. It returns None for the default safe file-backed source.

pub fn source(&self) -> &dyn TiffSource

Returns the backing source.

pub fn read_ifd_at_offset(&self, offset: u64) -> Result<Ifd>

Parse an IFD at an arbitrary file offset.

pub fn read_image_bytes(&self, ifd_index: usize) -> Result<Vec<u8>>

Decode an image into native-endian interleaved storage sample bytes.

pub fn read_image_bytes_from_ifd(&self, ifd: &Ifd) -> Result<Vec<u8>>

Decode an arbitrary IFD into native-endian interleaved storage sample bytes.

pub fn read_decoded_image_bytes(&self, ifd_index: usize) -> Result<Vec<u8>>

Decode an image into native-endian interleaved color-decoded pixel bytes.

pub fn read_decoded_image_bytes_from_ifd(&self, ifd: &Ifd) -> Result<Vec<u8>>

Decode an arbitrary IFD into native-endian interleaved color-decoded pixel bytes.

pub fn read_image_sample_bytes(&self, ifd_index: usize) -> Result<Vec<u8>>

Decode an image into native-endian interleaved storage sample bytes.

This is an explicit alias for Self::read_image_bytes.

pub fn read_image_sample_bytes_from_ifd(&self, ifd: &Ifd) -> Result<Vec<u8>>

Decode an arbitrary IFD into native-endian interleaved storage sample bytes.

This is an explicit alias for Self::read_image_bytes_from_ifd.

pub fn read_window_bytes( &self, ifd_index: usize, row_off: usize, col_off: usize, rows: usize, cols: usize, ) -> Result<Vec<u8>>

Decode a pixel window into native-endian interleaved storage sample bytes.

pub fn read_decoded_window_bytes( &self, ifd_index: usize, row_off: usize, col_off: usize, rows: usize, cols: usize, ) -> Result<Vec<u8>>

Decode a pixel window into native-endian interleaved color-decoded pixel bytes.

pub fn read_window_sample_bytes( &self, ifd_index: usize, row_off: usize, col_off: usize, rows: usize, cols: usize, ) -> Result<Vec<u8>>

Decode a pixel window into native-endian interleaved storage sample bytes.

This is an explicit alias for Self::read_window_bytes.

pub fn read_window_bytes_from_ifd( &self, ifd: &Ifd, row_off: usize, col_off: usize, rows: usize, cols: usize, ) -> Result<Vec<u8>>

Decode a pixel window from an arbitrary IFD into native-endian interleaved storage sample bytes.

pub fn read_decoded_window_bytes_from_ifd( &self, ifd: &Ifd, row_off: usize, col_off: usize, rows: usize, cols: usize, ) -> Result<Vec<u8>>

Decode a pixel window from an arbitrary IFD into native-endian interleaved color-decoded pixel bytes.

pub fn read_window_sample_bytes_from_ifd( &self, ifd: &Ifd, row_off: usize, col_off: usize, rows: usize, cols: usize, ) -> Result<Vec<u8>>

Decode a pixel window from an arbitrary IFD into native-endian interleaved storage sample bytes.

This is an explicit alias for Self::read_window_bytes_from_ifd.

pub fn read_band_bytes( &self, ifd_index: usize, band_index: usize, ) -> Result<Vec<u8>>

Decode a single storage-domain band into native-endian sample bytes.

pub fn read_band_bytes_from_ifd( &self, ifd: &Ifd, band_index: usize, ) -> Result<Vec<u8>>

Decode a single storage-domain band from an arbitrary IFD into native-endian sample bytes.

pub fn read_band_window_bytes( &self, ifd_index: usize, band_index: usize, row_off: usize, col_off: usize, rows: usize, cols: usize, ) -> Result<Vec<u8>>

Decode a pixel window from one storage-domain band into native-endian sample bytes.

pub fn read_band_window_bytes_from_ifd( &self, ifd: &Ifd, band_index: usize, row_off: usize, col_off: usize, rows: usize, cols: usize, ) -> Result<Vec<u8>>

Decode a pixel window from one storage-domain band in an arbitrary IFD into native-endian sample bytes.

pub fn read_window<T: TiffSample>( &self, ifd_index: usize, row_off: usize, col_off: usize, rows: usize, cols: usize, ) -> Result<ArrayD<T>>

Decode a window into a typed ndarray of storage-domain samples.

Single-band rasters are returned as shape [rows, cols]. Multi-band rasters are returned as shape [rows, cols, samples_per_pixel].

pub fn read_window_from_ifd<T: TiffSample>( &self, ifd: &Ifd, row_off: usize, col_off: usize, rows: usize, cols: usize, ) -> Result<ArrayD<T>>

Decode a window from an arbitrary IFD into a typed ndarray of storage-domain samples.

pub fn read_decoded_window<T: TiffSample>( &self, ifd_index: usize, row_off: usize, col_off: usize, rows: usize, cols: usize, ) -> Result<ArrayD<T>>

Decode a window into a typed ndarray of color-decoded pixels.

Single-channel decoded rasters are returned as shape [rows, cols]. Multi-channel decoded rasters are returned as shape [rows, cols, channels].

pub fn read_decoded_window_from_ifd<T: TiffSample>( &self, ifd: &Ifd, row_off: usize, col_off: usize, rows: usize, cols: usize, ) -> Result<ArrayD<T>>

Decode a window from an arbitrary IFD into a typed ndarray of color-decoded pixels.

pub fn read_window_samples<T: TiffSample>( &self, ifd_index: usize, row_off: usize, col_off: usize, rows: usize, cols: usize, ) -> Result<ArrayD<T>>

Decode a window into a typed ndarray of storage-domain samples.

Single-band rasters are returned as shape [rows, cols]. Multi-band rasters are returned as shape [rows, cols, samples_per_pixel].

pub fn read_window_samples_from_ifd<T: TiffSample>( &self, ifd: &Ifd, row_off: usize, col_off: usize, rows: usize, cols: usize, ) -> Result<ArrayD<T>>

Decode a window from an arbitrary IFD into a typed ndarray of storage-domain samples.

pub fn read_band<T: TiffSample>( &self, ifd_index: usize, band_index: usize, ) -> Result<ArrayD<T>>

Decode one storage-domain band into a typed [height, width] ndarray.

pub fn read_band_from_ifd<T: TiffSample>( &self, ifd: &Ifd, band_index: usize, ) -> Result<ArrayD<T>>

Decode one storage-domain band from an arbitrary IFD into a typed [height, width] ndarray.

pub fn read_band_window<T: TiffSample>( &self, ifd_index: usize, band_index: usize, row_off: usize, col_off: usize, rows: usize, cols: usize, ) -> Result<ArrayD<T>>

Decode a window from one storage-domain band into a typed [rows, cols] ndarray.

pub fn read_band_window_from_ifd<T: TiffSample>( &self, ifd: &Ifd, band_index: usize, row_off: usize, col_off: usize, rows: usize, cols: usize, ) -> Result<ArrayD<T>>

Decode a window from one storage-domain band in an arbitrary IFD into a typed [rows, cols] ndarray.

pub fn read_image<T: TiffSample>(&self, ifd_index: usize) -> Result<ArrayD<T>>

Decode an image into a typed ndarray of storage-domain samples.

Single-band rasters are returned as shape [height, width]. Multi-band rasters are returned as shape [height, width, samples_per_pixel].

pub fn read_image_from_ifd<T: TiffSample>(&self, ifd: &Ifd) -> Result<ArrayD<T>>

Decode an arbitrary IFD into a typed ndarray of storage-domain samples.

pub fn read_decoded_image<T: TiffSample>( &self, ifd_index: usize, ) -> Result<ArrayD<T>>

Decode an image into a typed ndarray of color-decoded pixels.

Single-channel decoded rasters are returned as shape [height, width]. Multi-channel decoded rasters are returned as shape [height, width, channels].

pub fn read_decoded_image_from_ifd<T: TiffSample>( &self, ifd: &Ifd, ) -> Result<ArrayD<T>>

Decode an arbitrary IFD into a typed ndarray of color-decoded pixels.

pub fn read_image_samples<T: TiffSample>( &self, ifd_index: usize, ) -> Result<ArrayD<T>>

Decode an image into a typed ndarray of storage-domain samples.

This is an explicit alias for Self::read_image.

pub fn read_image_samples_from_ifd<T: TiffSample>( &self, ifd: &Ifd, ) -> Result<ArrayD<T>>

Decode an arbitrary IFD into a typed ndarray of storage-domain samples.

This is an explicit alias for Self::read_image_from_ifd.